@@ -18,7 +18,7 @@ from selenium.webdriver import Chrome
 class SeleniumActions:
 
     @allure.step('Selenium actions initialization')
-    def __init__(self, driver, max_tries=3, max_pages=50):
+    def __init__(self, driver, max_tries=2, max_pages=50):
         self._list_of_elements = []
         self._web_element_type = "webelement"
         self._temp_element = None
@@ -179,7 +179,7 @@ class SeleniumActions:
             return True
 
     @allure.step
-    def repeat(self, command, proof, max_tries, maximum, reset):
+    def repeat(self, command, proof, max_tries=None, maximum=None, reset=None):
         """
         loop trying to fulfil a command (function), until a requirement satisfied (proof)
         :arg command : what to do ?
@@ -189,8 +189,8 @@ class SeleniumActions:
         :arg reset : optional arg, something to do after each try
         :returns True->Satisfied and proof exist False->error
         """
-        if max_tries > self.max_tries:
-            raise RuntimeError(f'you enter a very big number of tries, try again {max_tries} > {self.max_tries}')
+        if not max_tries or max_tries > self.max_tries:
+            max_tries = self.max_tries
 
         temp_global = self.global_timeout
         if maximum:
